<TS language="bs" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Desni klik za uređivanje adrese ili oznake</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Napravite novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopirajte trenutno odabranu adresu u sistemski meduspremnik</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopirajte</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zatvorite</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izbrišite trenutno odabranu odresu sa liste</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Unesite adresu ili oznaku za pretragu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvezite podatke trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvezite</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Iz&amp;brišite</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Izaberite adresu na koju ćete poslati novac</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Izaberite adresu na koju ćete primiti novac</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Izaberite</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adrese pošiljalaca</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adrese primalaca</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ovo su vaše Bitcoin adrese za slanje novca. Uvijek provjerite iznos i adresu primaoca prije slanja novca.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopirajte adresu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopirajte &amp;ozanku</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Uredite</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Izvezite listu adresa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Datoteka podataka odvojenih zarezima (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz neuspješan</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Došlo je do greške kod spašavanja liste adresa na %1. Molimo pokušajte ponovo.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Sve</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ovaj mjesec</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Prošli mjesec</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ove godine</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Datoteka podataka odvojenih zarezima (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz neuspješan</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvezite</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvezite podatke trenutne kartice u datoteku</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>